#!/usr/bin/env python

#-----------------------------------------------------------------------
# authorsearch.py
# Author: Bob Dondero
#-----------------------------------------------------------------------

import os
import sys
import sqlite3
import sqlalchemy
import sqlalchemy.orm
import dotenv
import database

dotenv.load_dotenv()
DATABASE_URL = os.environ['DATABASE_URL']

#-----------------------------------------------------------------------

def main():

    if len(sys.argv) != 2:
        print('Usage: python ' + sys.argv[0] + ' author',
            file=sys.stderr)
        sys.exit(1)

    author = sys.argv[1]

    try:
        engine = sqlalchemy.create_engine(DATABASE_URL)

        try:
            with sqlalchemy.orm.Session(engine) as session:

                query = (session.query(database.Book.isbn,
                    database.Book.title, database.Book.quantity)
                    .filter(database.Book.isbn == database.Author.isbn)
                    .filter(database.Author.author == author))

                table = query.all()
                for row in table:
                    print('ISBN:', row.isbn)
                    print('Title:', row.title)
                    print('Quantity:', row.quantity)
                    print()
        finally:
            engine.dispose()

    except Exception as ex:
        print(ex, file=sys.stderr)
        sys.exit(1)

#-----------------------------------------------------------------------

if __name__ == '__main__':
    main()
