#!/usr/bin/env python

#-----------------------------------------------------------------------
# display.py
# Author: Bob Dondero
#-----------------------------------------------------------------------

import os
import sys
import sqlite3
import sqlalchemy
import sqlalchemy.orm
import dotenv
import database

dotenv.load_dotenv()
DATABASE_URL = os.environ['DATABASE_URL']

#-----------------------------------------------------------------------

def main():

    if len(sys.argv) != 1:
        print('Usage: python ' + sys.argv[0], file=sys.stderr)
        sys.exit(1)

    try:
        engine = sqlalchemy.create_engine(DATABASE_URL)

        with sqlalchemy.orm.Session(engine) as session:

            print('-------------------------------------------')
            print('books')
            print('-------------------------------------------')
            query = session.query(database.Book)
            table = query.all()
            for row in table:
                print(row.isbn, row.title, row.quantity)

            print('-------------------------------------------')
            print('authors')
            print('-------------------------------------------')
            query = session.query(database.Author)
            table = query.all()
            for row in table:
                print(row.isbn, row.author)

            print('-------------------------------------------')
            print('customers')
            print('-------------------------------------------')
            query = session.query(database.Customer)
            table = query.all()
            for row in table:
                print(row.custid, row.custname, row.street, row.zipcode)

            print('-------------------------------------------')
            print('zipcodes')
            print('-------------------------------------------')
            query = session.query(database.Zipcode)
            table = query.all()
            for row in table:
                print(row.zipcode, row.city, row.state)

            print('-------------------------------------------')
            print('orders')
            print('-------------------------------------------')
            query = session.query(database.Order)
            table = query.all()
            for row in table:
                print(row.isbn, row.custid, row.quantity)

        engine.dispose()

    except Exception as ex:
        print(ex, file=sys.stderr)
        sys.exit(1)

#-----------------------------------------------------------------------

if __name__ == '__main__':
    main()
