#!/usr/bin/env python

#-----------------------------------------------------------------------
# recovery.py
# Author: Bob Dondero
#-----------------------------------------------------------------------

import os
import sys
import random
import sqlite3
import sqlalchemy
import sqlalchemy.orm
import dotenv
import database

dotenv.load_dotenv()
DATABASE_URL = os.environ['DATABASE_URL']

#-----------------------------------------------------------------------

def main():

    if len(sys.argv) != 1:
        print('Usage: python ' + sys.argv[0], file=sys.stderr)
        sys.exit(1)

    try:
        engine = sqlalchemy.create_engine(DATABASE_URL)
        with sqlalchemy.orm.Session(engine) as session:

            for i in range(20):

                query = (session.query(database.Order)
                    .filter(database.Order.isbn == '123')
                    .filter(database.Order.custid == '222'))
                row = query.one()
                row.quantity += 1

                # Simulate a HW/SW failure occurring randomly,
                # on average every 5th time through the loop.
                if random.randrange(5) == 0:
                    print('Simulated failure with i = %d' % i)
                    session.rollback()
                    print('Transaction rolled back.')
                    continue

                query = (session.query(database.Book)
                    .filter(database.Book.isbn == '123'))
                row = query.one()
                row.quantity -= 1

                session.commit()
                print('Transaction %d committed.' % i)

        engine.dispose()

    except Exception as ex:
        print(ex, file=sys.stderr)
        sys.exit(1)

#-----------------------------------------------------------------------

if __name__ == '__main__':
    main()
